FeatureOption

Enum FeatureOption 

#[repr(u32)]
pub enum FeatureOption { gfxd_stop_on_invalid = 0, gfxd_stop_on_end = 1, gfxd_emit_dec_color = 2, gfxd_emit_q_macro = 3, gfxd_emit_ext_macro = 4, }

Variants



gfxd_stop_on_invalid = 0

Stop execution when encountering an invalid macro.

Enabled by default.



gfxd_stop_on_end = 1

Stop execution when encountering a SPBranchList or SPEndDisplayList.

Enabled by default.



gfxd_emit_dec_color = 2

Print color components as decimal instead of hexadecimal.

Disabled by default.



gfxd_emit_q_macro = 3

Print fixed-point conversion q macros for fixed-point values.

Disabled by default.



gfxd_emit_ext_macro = 4

Emit non-standard macros.

Some commands are valid (though possibly meaningless), but have no macros associated with them, such as a standalone G_RDPHALF_1. When this feature is enabled, such a command will produce a non-standard gsDPHalf1 macro instead of a raw hexadecimal command.

Also enables some non-standard multi-packet texture loading macros.

Disabled by default.