pub unsafe extern "C" fn gfxd_execute() -> c_intExpand description
Start executing gfxd with the current settings.
For each macro, the macro handler registered with gfxd_macro_fn is
called.
Execution ends when the input ends, the macro handler returns non-zero,
when an invalid macro is encountered and gfxd_stop_on_invalid is
enabled, or when SPBranchList or SPEndDisplayList is encountered
and gfxd_stop_on_end is enabled.
If execution ends due to an invalid macro, -1 is returned.
If execution ends because the macro handler returns non-zero, the return value from the macro handler is returned.
Otherwise zero is returned.